==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/containerregistry/kotlin/inputs/PoliciesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerregistry.kotlin.inputs

import com.pulumi.azurenative.containerregistry.inputs.PoliciesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * The policies for a container registry.
 * @property exportPolicy The export policy for a container registry.
 * @property quarantinePolicy The quarantine policy for a container registry.
 * @property retentionPolicy The retention policy for a container registry.
 * @property trustPolicy The content trust policy for a container registry.
 */
public data class PoliciesArgs(
    public val exportPolicy: Output<ExportPolicyArgs>? = null,
    public val quarantinePolicy: Output<QuarantinePolicyArgs>? = null,
    public val retentionPolicy: Output<RetentionPolicyArgs>? = null,
    public val trustPolicy: Output<TrustPolicyArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.containerregistry.inputs.PoliciesArgs> {
    override fun toJava(): com.pulumi.azurenative.containerregistry.inputs.PoliciesArgs =
        com.pulumi.azurenative.containerregistry.inputs.PoliciesArgs.builder()
            .exportPolicy(exportPolicy?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .quarantinePolicy(quarantinePolicy?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .retentionPolicy(retentionPolicy?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .trustPolicy(trustPolicy?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [PoliciesArgs].
 */
@PulumiTagMarker
public class PoliciesArgsBuilder internal constructor() {
    private var exportPolicy: Output<ExportPolicyArgs>? = null

    private var quarantinePolicy: Output<QuarantinePolicyArgs>? = null

    private var retentionPolicy: Output<RetentionPolicyArgs>? = null

    private var trustPolicy: Output<TrustPolicyArgs>? = null

    /**
     * @param value The export policy for a container registry.
     */
    @JvmName("knsslfksssucubns")
    public suspend fun exportPolicy(`value`: Output<ExportPolicyArgs>) {
        this.exportPolicy = value
    }

    /**
     * @param value The quarantine policy for a container registry.
     */
    @JvmName("jrgaxplojclnkxvd")
    public suspend fun quarantinePolicy(`value`: Output<QuarantinePolicyArgs>) {
        this.quarantinePolicy = value
    }

    /**
     * @param value The retention policy for a container registry.
     */
    @JvmName("byelmdqywojksnpj")
    public suspend fun retentionPolicy(`value`: Output<RetentionPolicyArgs>) {
        this.retentionPolicy = value
    }

    /**
     * @param value The content trust policy for a container registry.
     */
    @JvmName("eydoylmehjerbvca")
    public suspend fun trustPolicy(`value`: Output<TrustPolicyArgs>) {
        this.trustPolicy = value
    }

    /**
     * @param value The export policy for a container registry.
     */
    @JvmName("ktrogqjexkhdicei")
    public suspend fun exportPolicy(`value`: ExportPolicyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.exportPolicy = mapped
    }

    /**
     * @param argument The export policy for a container registry.
     */
    @JvmName("cojyqabfeuackwsb")
    public suspend fun exportPolicy(argument: suspend ExportPolicyArgsBuilder.() -> Unit) {
        val toBeMapped = ExportPolicyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.exportPolicy = mapped
    }

    /**
     * @param value The quarantine policy for a container registry.
     */
    @JvmName("qbvedpajgodmqydr")
    public suspend fun quarantinePolicy(`value`: QuarantinePolicyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.quarantinePolicy = mapped
    }

    /**
     * @param argument The quarantine policy for a container registry.
     */
    @JvmName("qbkwpuhrsfuavjgn")
    public suspend fun quarantinePolicy(argument: suspend QuarantinePolicyArgsBuilder.() -> Unit) {
        val toBeMapped = QuarantinePolicyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.quarantinePolicy = mapped
    }

    /**
     * @param value The retention policy for a container registry.
     */
    @JvmName("cbcxsgykgqrboldk")
    public suspend fun retentionPolicy(`value`: RetentionPolicyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.retentionPolicy = mapped
    }

    /**
     * @param argument The retention policy for a container registry.
     */
    @JvmName("ubjakhfdwrsqidsg")
    public suspend fun retentionPolicy(argument: suspend RetentionPolicyArgsBuilder.() -> Unit) {
        val toBeMapped = RetentionPolicyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.retentionPolicy = mapped
    }

    /**
     * @param value The content trust policy for a container registry.
     */
    @JvmName("bkyhrbewyayuhutt")
    public suspend fun trustPolicy(`value`: TrustPolicyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.trustPolicy = mapped
    }

    /**
     * @param argument The content trust policy for a container registry.
     */
    @JvmName("vrapqdgyqdmswqoj")
    public suspend fun trustPolicy(argument: suspend TrustPolicyArgsBuilder.() -> Unit) {
        val toBeMapped = TrustPolicyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.trustPolicy = mapped
    }

    internal fun build(): PoliciesArgs = PoliciesArgs(
        exportPolicy = exportPolicy,
        quarantinePolicy = quarantinePolicy,
        retentionPolicy = retentionPolicy,
        trustPolicy = trustPolicy,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/containerregistry/kotlin/inputs/PoliciesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerregistry.kotlin.inputs

import com.pulumi.azurenative.containerregistry.inputs.PoliciesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * The policies for a container registry.
 * @property exportPolicy The export policy for a container registry.
 * @property quarantinePolicy The quarantine policy for a container registry.
 * @property retentionPolicy The retention policy for a container registry.
 * @property trustPolicy The content trust policy for a container registry.
 */
public data class PoliciesArgs(
    public val exportPolicy: Output<ExportPolicyArgs>? = null,
    public val quarantinePolicy: Output<QuarantinePolicyArgs>? = null,
    public val retentionPolicy: Output<RetentionPolicyArgs>? = null,
    public val trustPolicy: Output<TrustPolicyArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.containerregistry.inputs.PoliciesArgs> {
    override fun toJava(): com.pulumi.azurenative.containerregistry.inputs.PoliciesArgs =
        com.pulumi.azurenative.containerregistry.inputs.PoliciesArgs.builder()
            .exportPolicy(exportPolicy?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .quarantinePolicy(quarantinePolicy?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .retentionPolicy(retentionPolicy?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .trustPolicy(trustPolicy?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [PoliciesArgs].
 */
@PulumiTagMarker
public class PoliciesArgsBuilder internal constructor() {
    private var exportPolicy: Output<ExportPolicyArgs>? = null

    private var quarantinePolicy: Output<QuarantinePolicyArgs>? = null

    private var retentionPolicy: Output<RetentionPolicyArgs>? = null

    private var trustPolicy: Output<TrustPolicyArgs>? = null

    /**
     * @param value The export policy for a container registry.
     */
    @JvmName("ubbpiodbvvfjgvne")
    public suspend fun exportPolicy(`value`: Output<ExportPolicyArgs>) {
        this.exportPolicy = value
    }

    /**
     * @param value The quarantine policy for a container registry.
     */
    @JvmName("qkvmytrlalafsvyw")
    public suspend fun quarantinePolicy(`value`: Output<QuarantinePolicyArgs>) {
        this.quarantinePolicy = value
    }

    /**
     * @param value The retention policy for a container registry.
     */
    @JvmName("rdeccimokpdmplet")
    public suspend fun retentionPolicy(`value`: Output<RetentionPolicyArgs>) {
        this.retentionPolicy = value
    }

    /**
     * @param value The content trust policy for a container registry.
     */
    @JvmName("uopdfpcxgynufwas")
    public suspend fun trustPolicy(`value`: Output<TrustPolicyArgs>) {
        this.trustPolicy = value
    }

    /**
     * @param value The export policy for a container registry.
     */
    @JvmName("inybntvhhawysayw")
    public suspend fun exportPolicy(`value`: ExportPolicyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.exportPolicy = mapped
    }

    /**
     * @param argument The export policy for a container registry.
     */
    @JvmName("gtltgsuitncdhnef")
    public suspend fun exportPolicy(argument: suspend ExportPolicyArgsBuilder.() -> Unit) {
        val toBeMapped = ExportPolicyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.exportPolicy = mapped
    }

    /**
     * @param value The quarantine policy for a container registry.
     */
    @JvmName("cynyjlujueicbgqq")
    public suspend fun quarantinePolicy(`value`: QuarantinePolicyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.quarantinePolicy = mapped
    }

    /**
     * @param argument The quarantine policy for a container registry.
     */
    @JvmName("xxciasuneegycbkd")
    public suspend fun quarantinePolicy(argument: suspend QuarantinePolicyArgsBuilder.() -> Unit) {
        val toBeMapped = QuarantinePolicyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.quarantinePolicy = mapped
    }

    /**
     * @param value The retention policy for a container registry.
     */
    @JvmName("gsqsflookxfayqdd")
    public suspend fun retentionPolicy(`value`: RetentionPolicyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.retentionPolicy = mapped
    }

    /**
     * @param argument The retention policy for a container registry.
     */
    @JvmName("julknbfvawggyfvt")
    public suspend fun retentionPolicy(argument: suspend RetentionPolicyArgsBuilder.() -> Unit) {
        val toBeMapped = RetentionPolicyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.retentionPolicy = mapped
    }

    /**
     * @param value The content trust policy for a container registry.
     */
    @JvmName("uduvdhkxgwvnwghd")
    public suspend fun trustPolicy(`value`: TrustPolicyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.trustPolicy = mapped
    }

    /**
     * @param argument The content trust policy for a container registry.
     */
    @JvmName("icmdbxmtvfpxyngu")
    public suspend fun trustPolicy(argument: suspend TrustPolicyArgsBuilder.() -> Unit) {
        val toBeMapped = TrustPolicyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.trustPolicy = mapped
    }

    internal fun build(): PoliciesArgs = PoliciesArgs(
        exportPolicy = exportPolicy,
        quarantinePolicy = quarantinePolicy,
        retentionPolicy = retentionPolicy,
        trustPolicy = trustPolicy,
    )
}
